Use close_handle().
[nssm.git] / account.h
index 1719e6d..04cb10e 100644 (file)
--- a/account.h
+++ b/account.h
@@ -1,23 +1,28 @@
-#ifndef ACCOUNT_H
-#define ACCOUNT_H
-
-#include <ntsecapi.h>
-
-/* Not really an account.  The canonical name is NT Authority\System. */
-#define NSSM_LOCALSYSTEM_ACCOUNT _T("LocalSystem")
-/* Other well-known accounts which can start a service without a password. */
-#define NSSM_LOCALSERVICE_ACCOUNT _T("NT Authority\\LocalService")
-#define NSSM_NETWORKSERVICE_ACCOUNT _T("NT Authority\\NetworkService")
-/* This is explicitly a wide string. */
-#define NSSM_LOGON_AS_SERVICE_RIGHT L"SeServiceLogonRight"
-
-int open_lsa_policy(LSA_HANDLE *);
-int username_sid(const TCHAR *, SID **, LSA_HANDLE *);
-int username_sid(const TCHAR *, SID **);
-int username_equiv(const TCHAR *, const TCHAR *);
-int is_localsystem(const TCHAR *);
-const TCHAR *well_known_sid(SID *);
-const TCHAR *well_known_username(const TCHAR *);
-int grant_logon_as_service(const TCHAR *);
-
-#endif
+#ifndef ACCOUNT_H\r
+#define ACCOUNT_H\r
+\r
+#include <ntsecapi.h>\r
+\r
+/* Not really an account.  The canonical name is NT Authority\System. */\r
+#define NSSM_LOCALSYSTEM_ACCOUNT _T("LocalSystem")\r
+/* Other well-known accounts which can start a service without a password. */\r
+#define NSSM_LOCALSERVICE_ACCOUNT _T("NT Authority\\LocalService")\r
+#define NSSM_NETWORKSERVICE_ACCOUNT _T("NT Authority\\NetworkService")\r
+/* Virtual service accounts. */\r
+#define NSSM_VIRTUAL_SERVICE_ACCOUNT_DOMAIN _T("NT Service")\r
+/* This is explicitly a wide string. */\r
+#define NSSM_LOGON_AS_SERVICE_RIGHT L"SeServiceLogonRight"\r
+\r
+int open_lsa_policy(LSA_HANDLE *);\r
+int username_sid(const TCHAR *, SID **, LSA_HANDLE *);\r
+int username_sid(const TCHAR *, SID **);\r
+int username_equiv(const TCHAR *, const TCHAR *);\r
+int canonicalise_username(const TCHAR *, TCHAR **);\r
+int is_localsystem(const TCHAR *);\r
+TCHAR *virtual_account(const TCHAR *);\r
+int is_virtual_account(const TCHAR *, const TCHAR *);\r
+const TCHAR *well_known_sid(SID *);\r
+const TCHAR *well_known_username(const TCHAR *);\r
+int grant_logon_as_service(const TCHAR *);\r
+\r
+#endif\r